<html>
<header>
<title> Crea anno </title>
</header>
<body bgcolor=#ffffff>
<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################



include("./includes/funzioni.php");
$pag = "inizio.php";

unset($numconnessione);
$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
if ($id_utente and $id_utente == 1) {


if (!$numconnessione) {
include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
} # fine if (!$numconnessione)
$tableanni = $PHPR_TAB_PRE."anni";
$tableprivilegi = $PHPR_TAB_PRE."privilegi";

$filelock = fopen("./dati/anni.lock","w+");
flock($filelock,2);
$anno_esistente = esegui_query("select * from $tableanni where idanni = $anno");
if (numlin_query($anno_esistente) == 0) {

// creo la tabella con periodi settimanali e prezzi e la tabella con i nomi delle tariffe
$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
if ($importa_anno_prec == "SI") {
$anno_prec = $anno - 1;
$tablenometariffe_prec = $PHPR_TAB_PRE."ntariffe".$anno_prec;
$num_tariffe_tab = esegui_query("select nomecostoagg from $tablenometariffe_prec where idntariffe = 1");
$num_tariffe_tab = risul_query($num_tariffe_tab,0,nomecostoagg);
} # fine if ($importa_anno_prec == "SI")
else $num_tariffe_tab = 8;
$query = "create table $tableperiodi (idperiodi integer primary key, datainizio date not null, datafine date";
$query2 = "create table $tablenometariffe (idntariffe integer, nomecostoagg varchar(40), costosettimanale float8, costofinale float8, costopercentuale integer, costop_arrotond float8, regole varchar(40)";
for ($num1 = 1 ; $num1 <= $num_tariffe_tab ; $num1++) {
$nome_nuova_tariffa = "tariffa" . $num1;
$query .= ", $nome_nuova_tariffa float8";
$query2 .= ", $nome_nuova_tariffa varchar(40)";
} # fine for $num1
esegui_query($query.")");
esegui_query($query2.")");

# Creo la tabella delle prernotazioni
$tableprenotazioni = $PHPR_TAB_PRE."prenota".$anno;
esegui_query("create table $tableprenotazioni (idprenota integer primary key, idclienti integer, idappartamenti varchar(100), iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, idprenota_compagna text, tariffa text, costiaggiuntivi text, sconto float8, tariffa_tot float8, caparra float8, pagato float8, commento text, conferma varchar(4), datainserimento datetime, hostinserimento varchar(50), data_modifica datetime, utente_inserimento integer )");

# Creo la tabella per le regole di assegnazione
$tableregole = $PHPR_TAB_PRE."regole".$anno;
esegui_query("create table $tableregole (idregole integer, app_agenzia varchar(100), tariffa_per_app text, tariffa_per_utente text, iddatainizio integer, iddatafine integer, motivazione text)");

# Creo la tabella con i costi di gestione
$tablecosti = $PHPR_TAB_PRE."costi".$anno;
esegui_query("create table $tablecosti (idcosti integer unique,nome_costo text, val_costo float8, persona_costo text, provenienza_costo text, tipo_costo text, datainserimento datetime, hostinserimento varchar(50), utente_inserimento integer)");

# Creo la tabella per la storia entrate-uscite
$tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
esegui_query("create table $tablesoldi (idsoldi integer unique, motivazione text, saldo_prenota float8, saldo_cassa float8, soldi_prima float8, data_inserimento datetime, utente_inserimento integer)");

$tabelle_lock = array("$tableanni","$tableprenotazioni","$tablenometariffe","$tableperiodi","$tablecosti","$tableregole","$tablesoldi","$tableprivilegi");
if ($importa_anno_prec == "SI") {
$anno_prec = $anno - 1;
$tablenometariffe_prec = $PHPR_TAB_PRE."ntariffe".$anno_prec;
$tableprenota_prec = $PHPR_TAB_PRE."prenota".$anno_prec;
$tableperiodi_prec = $PHPR_TAB_PRE."periodi".$anno_prec;
$tableregole_prec = $PHPR_TAB_PRE."regole".$anno_prec;
$altre_tab_lock = array("$tableprenota_prec","$tablenometariffe_prec","$tableperiodi_prec","$tableregole_prec");
} # fine if ($importa_anno_prec == "SI")
else unset($altre_tab_lock);
$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);

# Inserisco l'anno nella tabella anni
esegui_query("insert into $tableanni (idanni,tipo_periodi) values ($anno,'$tipo_periodi')");

esegui_query("insert into $tablecosti (idcosti) values (0)");
esegui_query("insert into $tablesoldi (idsoldi,motivazione,soldi_prima) values ('1','soldi_prenotazioni_cancellate','0')");

// trovo il primo giorno di inizio/fine dell'anno (nel caso di periodi settimanali)
$numgiorno = 1;
do {
$nomegiorno = date("w",mktime(0,0,0,1,$numgiorno,$anno));
$numgiorno = $numgiorno + 1;
} while ($nomegiorno != $giorno_ini_fine) ;
$numgiorno  = $numgiorno - 1;

if ($tipo_periodi == "g") {
$numgiorno = 1;
$aggiungi_giorni = 1;
} # fine if ($tipo_periodi == "g")
else $aggiungi_giorni = 7;

if ($mese_ini > $mese_fine) {
echo mex("I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre",$pag).".<br>";
$mese_ini = 1;
$mese_fine = 12;
} # fine if ($mese_ini > $mese_fine)

$anno_fine = $anno + 1;

$idperiodi = 1;
$fileaperto = fopen("dati/selectperiodi$anno.1.php","a+");
flock($fileaperto,2);
fwrite($fileaperto,"<?php 
echo \"
");

do {
$datainizio = date("Y-m-d" , mktime(0,0,0,1,$numgiorno,$anno));
$annocreato = date("Y" , mktime(0,0,0,1,$numgiorno,$anno));
$mesecreato = date("n" , mktime(0,0,0,1,$numgiorno,$anno));
$nome_giorno = date("D" , mktime(0,0,0,1,$numgiorno,$anno));
$nome_mese = date("M" , mktime(0,0,0,1,$numgiorno,$anno));
$numero_giorno = date("d" , mktime(0,0,0,1,$numgiorno,$anno));
$numero_anno = $annocreato;
$numgiorno = $numgiorno + $aggiungi_giorni;
$datafine = date("Y-m-d" , mktime(0,0,0,1,$numgiorno,$anno));
$annocreato2 = date("Y" , mktime(0,0,0,1,$numgiorno,$anno));
$mesecreato2 = date("n" , mktime(0,0,0,1,$numgiorno,$anno));
if ($annocreato > $anno) {
$diff = $annocreato - $anno;
$mesecreato = ($diff * 12) + $mesecreato;
} # fine if ($annocreato > $anno)
if ($annocreato2 > $anno) {
$diff = $annocreato2 - $anno;
$mesecreato2 = ($diff * 12) + $mesecreato2;
} # fine if ($annocreato2 > $anno)
if ($mesecreato >= $mese_ini and $mesecreato <= $mese_fine) {
esegui_query("insert into $tableperiodi ( idperiodi, datainizio, datafine) values ( $idperiodi, '$datainizio', '$datafine')");
if ($tipo_periodi == "g") {
if ($nome_giorno == "Sun") $nome_giorno = mex(" Do",$pag);
if ($nome_giorno == "Mon") $nome_giorno = mex(" Lu",$pag);
if ($nome_giorno == "Tue") $nome_giorno = mex(" Ma",$pag);
if ($nome_giorno == "Wed") $nome_giorno = mex(" Me",$pag);
if ($nome_giorno == "Thu") $nome_giorno = mex(" Gi",$pag);
if ($nome_giorno == "Fri") $nome_giorno = mex(" Ve",$pag);
if ($nome_giorno == "Sat") $nome_giorno = mex(" Sa",$pag);
} # fine if ($tipo_periodi == "g")
else $nome_giorno = "";
if ($nome_mese == "Jan") $nome_mese = mex("Gen",$pag);
if ($nome_mese == "Feb") $nome_mese = mex("Feb",$pag);
if ($nome_mese == "Mar") $nome_mese = mex("Mar",$pag);
if ($nome_mese == "Apr") $nome_mese = mex("Apr",$pag);
if ($nome_mese == "May") $nome_mese = mex("Mag",$pag);
if ($nome_mese == "Jun") $nome_mese = mex("Giu",$pag);
if ($nome_mese == "Jul") $nome_mese = mex("Lug",$pag);
if ($nome_mese == "Aug") $nome_mese = mex("Ago",$pag);
if ($nome_mese == "Sep") $nome_mese = mex("Set",$pag);
if ($nome_mese == "Oct") $nome_mese = mex("Ott",$pag);
if ($nome_mese == "Nov") $nome_mese = mex("Nov",$pag);
if ($nome_mese == "Dec") $nome_mese = mex("Dic",$pag);
fwrite($fileaperto,"<option value=\\\"$datainizio\\\">$nome_mese $numero_giorno$nome_giorno, $numero_anno</option>
");
$idperiodi = $idperiodi + 1;
$datafine2 = $datafine;
} # fine if ($mesecreato >= $mese_ini and $mesecreato <= $mese_fine)
} while ($annocreato2 <= $anno_fine or $mesecreato2 == 25);

$numero_mese = substr($datafine2,5,2);
if ($numero_mese == "01") $nome_mese = mex("Gen",$pag);
if ($numero_mese == "02") $nome_mese = mex("Feb",$pag);
if ($numero_mese == "03") $nome_mese = mex("Mar",$pag);
if ($numero_mese == "04") $nome_mese = mex("Apr",$pag);
if ($numero_mese == "05") $nome_mese = mex("Mag",$pag);
if ($numero_mese == "06") $nome_mese = mex("Giu",$pag);
if ($numero_mese == "07") $nome_mese = mex("Lug",$pag);
if ($numero_mese == "08") $nome_mese = mex("Ago",$pag);
if ($numero_mese == "09") $nome_mese = mex("Set",$pag);
if ($numero_mese == "10") $nome_mese = mex("Ott",$pag);
if ($numero_mese == "11") $nome_mese = mex("Nov",$pag);
if ($numero_mese == "12") $nome_mese = mex("Dic",$pag);
$numero_giorno = substr($datafine2,8,2);
$numero_anno = substr($datafine2,0,4);
fwrite($fileaperto,"<option value=\\\"$datafine2\\\">$nome_mese $numero_giorno, $numero_anno</option>
");
fwrite($fileaperto,"\";
?>");
flock($fileaperto,3);
fclose($fileaperto);
copy ("dati/selectperiodi$anno.1.php","dati/selperiodimenu$anno.1.php");

# Importo eventuali prenotazioni, tariffe e regole dell'anno precedente
if ($importa_anno_prec == "SI") {
$tableprenota = $tableprenotazioni;
$data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
$data_inizio_periodi = risul_query($data_inizio_periodi,0,datainizio);
$ini_periodo_interferenza =  esegui_query("select * from $tableperiodi_prec where datainizio = '$data_inizio_periodi'");
$num_periodo_interferenza = numlin_query($ini_periodo_interferenza);
$tipo_periodi_prec = esegui_query("select * from $tableanni where idanni = $anno_prec");
$tipo_periodi_prec = risul_query($tipo_periodi_prec,0,tipo_periodi);
if ($tipo_periodi_prec != $tipo_periodi) $num_periodo_interferenza = 0;
if ($num_periodo_interferenza == 0) {
echo mex("Non ci sono periodi che riguardano il ",$pag).$anno.mex(" nel ",$pag).$anno_prec.mex(", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3",$pag).".<br>";
} # fine if ($num_periodo_interferenza == 0)
else {
$id_data_fine_periodi = esegui_query("select max(idperiodi) from $tableperiodi");
$id_data_fine_periodi = risul_query($id_data_fine_periodi,0,0);
$id_data_ini_periodi_prec = risul_query($ini_periodo_interferenza,0,idperiodi);
$id_data_fine_periodi_prec = esegui_query("select max(idperiodi) from $tableperiodi_prec");
$id_data_fine_periodi_prec = risul_query($id_data_fine_periodi_prec,0,0);
$num_periodi_prec = $id_data_fine_periodi_prec - $id_data_ini_periodi_prec + 1;
if ($num_periodi_prec > $id_data_fine_periodi) {
$id_data_fine_periodi_prec = $id_data_ini_periodi_prec + $id_data_fine_periodi - 1;
$prenota_non_importabili = esegui_query("select * from $tableprenota_prec where iddatafine > $id_data_fine_periodi_prec ");
$num_prenota_non_importabili = numlin_query($prenota_non_importabili);
if ($num_prenota_non_importabili != 0) {
echo "<font color=\"red\"><b>".mex("Attenzione</b></font>: i periodi del ",$pag).$anno_prec.mex(" finivano dopo quelli del ",$pag).
$anno.mex(" e vi erano",$pag)." <b>$num_prenota_non_importabili</b> ".mex("prenotazioni che finivano dopo il limite posto al ",
$pag).$anno.mex(", queste prenotazioni non sono state importate",$pag).".<br>";
} # fine if ($num_prenota_non_importabili != 0)
} # fine if ($num_periodi_prec > $id_data_fine_periodi)
esegui_query("insert into $tableprenota select * from $tableprenota_prec where iddatainizio >= '$id_data_ini_periodi_prec' and iddatafine <= '$id_data_fine_periodi_prec' ");
$prenota_importate = esegui_query("select * from $tableprenota_prec where iddatainizio >= '$id_data_ini_periodi_prec' and iddatafine <= '$id_data_fine_periodi_prec' order by idprenota ");
$num_prenota_importate = numlin_query($prenota_importate);
for ($num1 = 0 ; $num1 < $num_prenota_importate ; $num1 = $num1 + 1) {
$idprenota = risul_query($prenota_importate,$num1,idprenota);
$iddatainizio = risul_query($prenota_importate,$num1,iddatainizio);
$iddatainizio = $iddatainizio - $id_data_ini_periodi_prec + 1;
$iddatafine = risul_query($prenota_importate,$num1,iddatafine);
$iddatafine = $iddatafine - $id_data_ini_periodi_prec + 1;
esegui_query("update $tableprenota set iddatainizio = '$iddatainizio' where idprenota = '$idprenota'");
esegui_query("update $tableprenota set iddatafine = '$iddatafine' where idprenota = '$idprenota'");
} # fine for $num1
$prenota_gia_iniziate = esegui_query("select * from $tableprenota_prec where iddatainizio < $id_data_ini_periodi_prec and iddatafine >= $id_data_ini_periodi_prec and iddatafine <= $id_data_fine_periodi_prec ");
$num_prenota_gia_iniziate = numlin_query($prenota_gia_iniziate);
for ($num1 = 0 ; $num1 < $num_prenota_gia_iniziate ; $num1 = $num1 + 1) {
$idprenota = risul_query($prenota_gia_iniziate,$num1,idprenota);
$idclienti = risul_query($prenota_gia_iniziate,$num1,idclienti);
$idappartamenti = risul_query($prenota_gia_iniziate,$num1,idappartamenti);
$iddatafine = risul_query($prenota_gia_iniziate,$num1,iddatafine);
$iddatafine = $iddatafine - $id_data_ini_periodi_prec + 1;
$datainserimento = risul_query($prenota_gia_iniziate,$num1,datainserimento);
$hostinserimento = risul_query($prenota_gia_iniziate,$num1,hostinserimento);
$data_modifica = risul_query($prenota_gia_iniziate,$num1,data_modifica);
esegui_query("insert into $tableprenota (idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,datainserimento,hostinserimento) values ('$idprenota','$idclienti','$idappartamenti','0',$iddatafine,'k','$datainserimento','$hostinserimento') ");
} # fine for $num1
$tariffe_importate = esegui_query("select * from $tableperiodi_prec where ( tariffa1 != '' or  tariffa2 != '' or tariffa3 != '') and idperiodi >= '$id_data_ini_periodi_prec' and idperiodi <= '$id_data_fine_periodi_prec' ");
$num_tariffe_iportate = numlin_query($tariffe_importate);
for ($num1 = 0 ; $num1 < $num_tariffe_iportate ; $num1 = $num1 + 1) {
$idperiodi = risul_query($tariffe_importate,$num1,idperiodi);
$idperiodi = $idperiodi - $id_data_ini_periodi_prec + 1;
$tariffa1 = risul_query($tariffe_importate,$num1,tariffa1);
$tariffa2 = risul_query($tariffe_importate,$num1,tariffa2);
$tariffa3 = risul_query($tariffe_importate,$num1,tariffa3);
if ($tariffa1) {
esegui_query("update $tableperiodi set tariffa1 = '$tariffa1' where idperiodi = $idperiodi ");
} # fine if ($tariffa1)
if ($tariffa2) {
esegui_query("update $tableperiodi set tariffa2 = '$tariffa2' where idperiodi = $idperiodi ");
} # fine if ($tariffa2)
if ($tariffa3) {
esegui_query("update $tableperiodi set tariffa3 = '$tariffa3' where idperiodi = $idperiodi ");
} # fine if ($tariffa3)
} # fine for $num1
$regole_prec = esegui_query("select * from $tableregole_prec where iddatafine >= '$id_data_ini_periodi_prec' ");
$num_regole_prec = numlin_query($regole_prec);
for ($num1 = 0 ; $num1 < $num_regole_prec ; $num1 = $num1 + 1) {
$idregole = risul_query($regole_prec,$num1,idregole);
$app_agenzia = risul_query($regole_prec,$num1,app_agenzia);
$iddatainizio = risul_query($regole_prec,$num1,iddatainizio);
if ($iddatainizio < $id_data_ini_periodi_prec) { $iddatainizio = $id_data_ini_periodi_prec; }
$iddatainizio = $iddatainizio - $id_data_ini_periodi_prec + 1;
$iddatafine = risul_query($regole_prec,$num1,iddatafine);
if ($iddatafine > $id_data_fine_periodi_prec) { $iddatafine = $id_data_fine_periodi_prec; }
$iddatafine = $iddatafine - $id_data_ini_periodi_prec + 1;
esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ('$idregole','$app_agenzia','$iddatainizio','$iddatafine') ");
} # fine for $num1
} # fine else if ($num_periodo_interferenza == 0)
$num_tariffe_prec = esegui_query("select nomecostoagg from $tablenometariffe_prec where idntariffe = 1");
$num_tariffe_prec = risul_query($num_tariffe_prec,0,nomecostoagg);
$colonne = "idntariffe,nomecostoagg,costosettimanale,costofinale,costopercentuale,costop_arrotond,regole";
for ($num1 = 1 ; $num1 <= $num_tariffe_prec ; $num1++) {
$nome_nuova_tariffa = "tariffa" . $num1;
$colonne .= ",$nome_nuova_tariffa";
} # fine for $num1
esegui_query("insert into $tablenometariffe ($colonne) select $colonne from $tablenometariffe_prec");
esegui_query("insert into $tableregole select * from $tableregole_prec where tariffa_per_app != ''");
esegui_query("insert into $tableregole select * from $tableregole_prec where tariffa_per_utente != ''");
$privilegi_prec = esegui_query("select * from $tableprivilegi where anno = '$anno_prec'");
for ($num1 = 0 ; $num1 < numlin_query($privilegi_prec) ; $num1++) {
$idutente_p = risul_query($privilegi_prec,$num1,idutente);
$regole1_consentite_p = risul_query($privilegi_prec,$num1,regole1_consentite);
$tariffe_consentite_p = risul_query($privilegi_prec,$num1,tariffe_consentite);
$costi_agg_consentiti_p = risul_query($privilegi_prec,$num1,costi_agg_consentiti);
$contratti_consentiti_p = risul_query($privilegi_prec,$num1,contratti_consentiti);
$priv_ins_prenota_p = risul_query($privilegi_prec,$num1,priv_ins_prenota);
$priv_mod_prenota_p = risul_query($privilegi_prec,$num1,priv_mod_prenota);
$priv_mod_pers_p = risul_query($privilegi_prec,$num1,priv_mod_pers);
$priv_ins_clienti_p = risul_query($privilegi_prec,$num1,priv_ins_clienti);
$prefisso_clienti_p = risul_query($privilegi_prec,$num1,prefisso_clienti);
$priv_ins_costi_p = risul_query($privilegi_prec,$num1,priv_ins_costi);
$priv_vedi_tab_p = risul_query($privilegi_prec,$num1,priv_vedi_tab);
$priv_ins_tariffe_p = risul_query($privilegi_prec,$num1,priv_ins_tariffe);
$priv_ins_regole_p = risul_query($privilegi_prec,$num1,priv_ins_regole);
esegui_query("insert into $tableprivilegi (idutente,anno,regole1_consentite,tariffe_consentite,costi_agg_consentiti,contratti_consentiti,priv_ins_prenota,priv_mod_prenota,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_ins_costi,priv_vedi_tab,priv_ins_tariffe,priv_ins_regole) values ('$idutente_p','$anno','$regole1_consentite_p','$tariffe_consentite_p','$costi_agg_consentiti_p','$contratti_consentiti_p','$priv_ins_prenota_p','$priv_mod_prenota_p','$priv_mod_pers_p','$priv_ins_clienti_p','$prefisso_clienti_p','$priv_ins_costi_p','$priv_vedi_tab_p','$priv_ins_tariffe_p','$priv_ins_regole_p')");
} # fine for $num1
$inserisci_in_ntariffe = "NO";
} # fine if ($importa_anno_prec == "SI")

if ($inserisci_in_ntariffe != "NO") {
# rigo 1: nomi tariffe; 2-3: caparra (% e arrotondo).
for ($numtariffe =1 ; $numtariffe <= 3 ; $numtariffe = $numtariffe + 1) {
esegui_query("insert into $tablenometariffe (idntariffe) values ($numtariffe)");
} # fine for $numtariffe
esegui_query("update $tablenometariffe set nomecostoagg = 8 where idntariffe = 1");
esegui_query("update $tablenometariffe set regole = 4 where idntariffe = 1");
} # fine if ($inserisci_in_ntariffe != "NO")

unlock_tabelle($tabelle_lock);

} # fine if (numlin_query($anno_esistente) == 0)
else echo mex("Anno gi creato",$pag).".<br>";

flock($filelock,3);
fclose($filelock);
unlink("./dati/anni.lock");


echo "<br> ".mex("Anno ",$pag).$anno.mex(" creato",$pag)."! <br><br>
<form method=\"post\" action=\"inizio.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
<input type=\"submit\" name=\"ok\" value=\"OK\"><br>
</form>";



} # fine if ($id_utente and $id_utente == 1)



?>

</body>
</html>
